@@ -14,7 +14,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import flask
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 from oslo_middleware import base
@@ -23,6 +22,7 @@ from oslo_serialization import jsonutils
 from oslo_utils import strutils
 import webob.dec
 
+import designate.conf
 from designate import context
 from designate import exceptions
 from designate import notifications
@@ -30,6 +30,7 @@ from designate import objects
 from designate.objects.adapters import DesignateAdapter
 
 
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -39,7 +40,7 @@ def auth_pipeline_factory(loader, global_conf, **local_conf):
 
     Code nabbed from cinder.
     """
-    pipeline = local_conf[cfg.CONF['service:api'].auth_strategy]
+    pipeline = local_conf[CONF['service:api'].auth_strategy]
     pipeline = pipeline.split()
     LOG.info('Getting auth pipeline: %s', pipeline[:-1])
     filters = [loader.get_filter(n) for n in pipeline[:-1]]
@@ -130,7 +131,7 @@ class ContextMiddleware(base.Middleware):
 
 class KeystoneContextMiddleware(ContextMiddleware):
     def __init__(self, application):
-        super(KeystoneContextMiddleware, self).__init__(application)
+        super().__init__(application)
 
         LOG.info('Starting designate keystonecontext middleware')
 
@@ -170,7 +171,7 @@ class KeystoneContextMiddleware(ContextMiddleware):
 
 class NoAuthContextMiddleware(ContextMiddleware):
     def __init__(self, application):
-        super(NoAuthContextMiddleware, self).__init__(application)
+        super().__init__(application)
 
         LOG.info('Starting designate noauthcontext middleware')
 
@@ -188,7 +189,7 @@ class NoAuthContextMiddleware(ContextMiddleware):
 
 class TestContextMiddleware(ContextMiddleware):
     def __init__(self, application, tenant_id=None, user_id=None):
-        super(TestContextMiddleware, self).__init__(application)
+        super().__init__(application)
 
         LOG.critical('Starting designate testcontext middleware')
         LOG.critical('**** DO NOT USE IN PRODUCTION ****')
@@ -200,7 +201,8 @@ class TestContextMiddleware(ContextMiddleware):
         headers = request.headers
 
         all_tenants = strutils.bool_from_string(
-            headers.get('X-Test-All-Tenants', 'False'))
+            headers.get('X-Test-All-Tenants', 'False')
+        )
 
         role_header = headers.get('X-Test-Role', None)
         role_header = role_header.lower() if role_header else None
@@ -223,12 +225,12 @@ class TestContextMiddleware(ContextMiddleware):
 
 class MaintenanceMiddleware(base.Middleware):
     def __init__(self, application):
-        super(MaintenanceMiddleware, self).__init__(application)
+        super().__init__(application)
 
         LOG.info('Starting designate maintenance middleware')
 
-        self.enabled = cfg.CONF['service:api'].maintenance_mode
-        self.role = cfg.CONF['service:api'].maintenance_mode_role
+        self.enabled = CONF['service:api'].maintenance_mode
+        self.role = CONF['service:api'].maintenance_mode_role
 
     def process_request(self, request):
         # If maintaince mode is not enabled, pass the request on as soon as
@@ -257,7 +259,7 @@ class NormalizeURIMiddleware(base.Middleware):
 
 class FaultWrapperMiddleware(base.Middleware):
     def __init__(self, application):
-        super(FaultWrapperMiddleware, self).__init__(application)
+        super().__init__(application)
 
         LOG.info('Starting designate faultwrapper middleware')
 
@@ -338,7 +340,7 @@ class FaultWrapperMiddleware(base.Middleware):
 class APIv2ValidationErrorMiddleware(base.Middleware):
 
     def __init__(self, application):
-        super(APIv2ValidationErrorMiddleware, self).__init__(application)
+        super().__init__(application)
         self.api_version = 'API_v2'
         LOG.info('Starting designate validation middleware')
 
