@@ -15,15 +15,16 @@ import ipaddress
 import os.path
 import urllib
 
-from oslo_config import cfg
 from oslo_log import log as logging
 import requests
 
 from designate.backend import base
+import designate.conf
 from designate import exceptions
 
+
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 
 
 class PDNS4Backend(base.Backend):
@@ -32,7 +33,7 @@ class PDNS4Backend(base.Backend):
     __backend_status__ = 'integrated'
 
     def __init__(self, target):
-        super(PDNS4Backend, self).__init__(target)
+        super().__init__(target)
 
         self.api_endpoint = self.options.get('api_endpoint')
         self.api_token = self.options.get('api_token')
@@ -45,7 +46,7 @@ class PDNS4Backend(base.Backend):
 
     def _build_url(self, zone=''):
         r_url = urllib.parse.urlparse(self.api_endpoint)
-        return "%s://%s/api/v1/servers/localhost/zones%s%s" % (
+        return "{}://{}/api/v1/servers/localhost/zones{}{}".format(
             r_url.scheme, r_url.netloc, '/' if zone else '', zone)
 
     def _check_zone_exists(self, zone):
@@ -83,8 +84,11 @@ class PDNS4Backend(base.Backend):
         masters = []
         for master in self.masters:
             host = master.host
-            if ipaddress.ip_address(host).version == 6:
-                host = '[%s]' % host
+            try:
+                if ipaddress.ip_address(host).version == 6:
+                    host = '[%s]' % host
+            except ValueError:
+                pass
             masters.append('%s:%d' % (host, master.port))
 
         data = {
@@ -125,7 +129,7 @@ class PDNS4Backend(base.Backend):
                     LOG.error('Could not delete errored zone %s', zone)
             raise exceptions.Backend(e)
 
-    def delete_zone(self, context, zone):
+    def delete_zone(self, context, zone, zone_params=None):
         """Delete a DNS zone"""
 
         # First verify that the zone exists -- If it's not present
