@@ -13,15 +13,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
+from designate.common.decorators import rpc as rpc_decorator
 from designate.common import profiler
-from designate.loggingutils import rpc_logging
+import designate.conf
 from designate import rpc
 
+
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 CENTRAL_API = None
@@ -33,8 +34,8 @@ def reset():
 
 
 @profiler.trace_cls("rpc")
-@rpc_logging(LOG, 'central')
-class CentralAPI(object):
+@rpc_decorator.rpc_logging(LOG, 'central')
+class CentralAPI:
     """
     Client side of the central RPC API.
 
@@ -67,21 +68,26 @@ class CentralAPI(object):
         6.3 - Changed 'update_status' method args
         6.4 - Removed unused record and diagnostic methods
         6.5 - Removed additional unused methods
+        6.6 - Add methods for shared zones
+        6.7 - Add increment_zone_serial
+        6.8 - Add managed recordset methods
+        6.9 - Removed unused methods
+        6.10 - Add Zone Pool Move method
     """
-    RPC_API_VERSION = '6.5'
+    RPC_API_VERSION = '6.10'
 
     # This allows us to mark some methods as not logged.
     # This can be for a few reasons - some methods my not actually call over
     # RPC, or may be so noisy that logging them is not useful
     # This should be an array of strings that match the function names
-    LOGGING_BLACKLIST = ['update_service_status']
+    RPC_LOGGING_DISALLOW = ['update_service_status']
 
     def __init__(self, topic=None):
-        self.topic = topic if topic else cfg.CONF['service:central'].topic
+        self.topic = topic if topic else CONF['service:central'].topic
 
         target = messaging.Target(topic=self.topic,
                                   version=self.RPC_API_VERSION)
-        self.client = rpc.get_client(target, version_cap='6.5')
+        self.client = rpc.get_client(target, version_cap='6.10')
 
     @classmethod
     def get_instance(cls):
@@ -140,6 +146,9 @@ class CentralAPI(object):
         return self.client.call(context, 'get_tenant', tenant_id=tenant_id)
 
     # Zone Methods
+    def increment_zone_serial(self, context, zone):
+        return self.client.call(context, 'increment_zone_serial', zone=zone)
+
     def create_zone(self, context, zone):
         return self.client.call(context, 'create_zone', zone=zone)
 
@@ -167,6 +176,32 @@ class CentralAPI(object):
         return self.client.call(context, 'purge_zones',
                                 criterion=criterion, limit=limit)
 
+    def pool_move_zone(self, context, zone_id, target_pool_id):
+        return self.client.call(context, 'pool_move_zone',
+                                zone_id=zone_id,
+                                target_pool_id=target_pool_id)
+
+    # Shared Zone methods
+    def share_zone(self, context, zone_id, shared_zone):
+        return self.client.call(context, 'share_zone', zone_id=zone_id,
+                                shared_zone=shared_zone)
+
+    def unshare_zone(self, context, zone_id, zone_share_id):
+        return self.client.call(context, 'unshare_zone',
+                                zone_id=zone_id, zone_share_id=zone_share_id)
+
+    def find_shared_zones(self, context, criterion=None, marker=None,
+                          limit=None, sort_key=None, sort_dir=None):
+        return self.client.call(
+            context, 'find_shared_zones', criterion=criterion, marker=marker,
+            limit=limit, sort_key=sort_key, sort_dir=sort_dir)
+
+    def get_shared_zone(self, context, zone_id, zone_share_id):
+        return self.client.call(
+            context, 'get_shared_zone', zone_id=zone_id,
+            zone_share_id=zone_share_id
+        )
+
     # TLD Methods
     def create_tld(self, context, tld):
         return self.client.call(context, 'create_tld', tld=tld)
@@ -202,8 +237,16 @@ class CentralAPI(object):
                                 limit=limit, sort_key=sort_key,
                                 sort_dir=sort_dir, force_index=force_index)
 
-    def find_recordset(self, context, criterion=None):
-        return self.client.call(context, 'find_recordset', criterion=criterion)
+    def create_managed_records(self, context, zone_id, records_values,
+                               recordset_values):
+        return self.client.call(context, 'create_managed_records',
+                                zone_id=zone_id, records_values=records_values,
+                                recordset_values=recordset_values)
+
+    def delete_managed_records(self, context, zone_id=None, criterion=None):
+        return self.client.call(context, 'delete_managed_records',
+                                zone_id=zone_id,
+                                criterion=criterion)
 
     def export_zone(self, context, zone_id):
         return self.client.call(context, 'export_zone', zone_id=zone_id)
@@ -220,13 +263,6 @@ class CentralAPI(object):
                                 recordset_id=recordset_id,
                                 increment_serial=increment_serial)
 
-    # Record Methods
-    def find_records(self, context, criterion=None, marker=None, limit=None,
-                     sort_key=None, sort_dir=None):
-        return self.client.call(context, 'find_records', criterion=criterion,
-                                marker=marker, limit=limit, sort_key=sort_key,
-                                sort_dir=sort_dir)
-
     # Misc. Report combining counts for tenants, zones and records
     def count_report(self, context, criterion=None):
         return self.client.call(context, 'count_report', criterion=criterion)
@@ -356,10 +392,6 @@ class CentralAPI(object):
         return self.client.call(context, 'get_zone_import',
                                 zone_import_id=zone_import_id)
 
-    def update_zone_import(self, context, zone_import):
-        return self.client.call(context, 'update_zone_import',
-                                zone_import=zone_import)
-
     def delete_zone_import(self, context, zone_import_id):
         return self.client.call(context, 'delete_zone_import',
                                 zone_import_id=zone_import_id)
