@@ -16,36 +16,40 @@
 # Copied partially from nova
 import concurrent.futures
 import futurist
-from neutronclient.common import exceptions as neutron_exceptions
-from neutronclient.v2_0 import client as clientv20
-from oslo_config import cfg
+from keystoneauth1 import session
+from keystoneauth1 import token_endpoint
+import openstack
+from openstack import exceptions as sdk_exceptions
 from oslo_log import log as logging
 
+import designate.conf
 from designate import exceptions
 from designate.network_api import base
+from designate import version
 
-CONF = cfg.CONF
+
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
 def get_client(context, endpoint):
-    params = {
-        'endpoint_url': endpoint,
-        'timeout': CONF['network_api:neutron'].timeout,
-        'insecure': CONF['network_api:neutron'].insecure,
-        'ca_cert': CONF['network_api:neutron'].ca_certificates_file,
-    }
+    verify = True
+    if CONF['network_api:neutron'].insecure:
+        verify = False
+    elif CONF['network_api:neutron'].ca_certificates_file:
+        verify = CONF['network_api:neutron'].ca_certificates_file
 
-    if context.auth_token:
-        params['token'] = context.auth_token
-        params['auth_strategy'] = None
-    elif CONF['network_api:neutron'].admin_username is not None:
-        params['username'] = CONF['network_api:neutron'].admin_username
-        params['project_name'] = CONF['network_api:neutron'].admin_tenant_name
-        params['password'] = CONF['network_api:neutron'].admin_password
-        params['auth_url'] = CONF['network_api:neutron'].auth_url
-        params['auth_strategy'] = CONF['network_api:neutron'].auth_strategy
-    return clientv20.Client(**params)
+    auth_token = token_endpoint.Token(endpoint, context.auth_token)
+
+    user_session = session.Session(
+        auth=auth_token,
+        verify=verify,
+        cert=CONF['network_api:neutron'].client_certificate_file,
+        timeout=CONF['network_api:neutron'].timeout,
+        app_name='designate',
+        app_version=version.version_info.version_string())
+
+    return openstack.connection.Connection(session=user_session)
 
 
 class NeutronNetworkAPI(base.NetworkAPI):
@@ -91,18 +95,20 @@ class NeutronNetworkAPI(base.NetworkAPI):
                   {'region': region, 'endpoint': endpoint})
         client = get_client(context, endpoint=endpoint)
         try:
-            fips = client.list_floatingips(project_id=project_id)
-            for fip in fips['floatingips']:
+            fips = client.network.ips(project_id=project_id)
+            for fip in fips:
                 yield {
                     'id': fip['id'],
                     'address': fip['floating_ip_address'],
                     'region': region
                 }
-        except neutron_exceptions.Unauthorized:
+        except sdk_exceptions.HttpException as http_ex:
             LOG.warning(
                 'Failed fetching floating ips from %(region)s @ %(endpoint)s'
-                'due to an Unauthorized error',
-                {'region': region, 'endpoint': endpoint}
+                'due to a %(cause)s error',
+                {'region': region,
+                 'endpoint': endpoint,
+                 'cause': http_ex.message}
             )
         except Exception:
             LOG.error(
