@@ -16,20 +16,13 @@
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_policy import policy
-from oslo_policy import opts
 
-from designate import exceptions
 from designate.common import policies
+import designate.conf
+from designate import exceptions
 
 
-CONF = cfg.CONF
-
-# Add the default policy opts
-# TODO(gmann): Remove setting the default value of config policy_file
-# once oslo_policy change the default value to 'policy.yaml'.
-# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
-DEFAULT_POLICY_FILE = 'policy.yaml'
-opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+CONF = designate.conf.CONF
 
 LOG = logging.getLogger(__name__)
 
@@ -45,7 +38,7 @@ def reset():
 
 
 def set_rules(data, default_rule=None, overwrite=True):
-    default_rule = default_rule or cfg.CONF.policy_default_rule
+    default_rule = default_rule or CONF.policy_default_rule
     if not _ENFORCER:
         LOG.debug("Enforcer not present, recreating at rules stage.")
         init()
@@ -73,10 +66,7 @@ def init(default_rule=None, policy_file=None):
 
 
 def check(rule, ctxt, target=None, do_raise=True, exc=exceptions.Forbidden):
-    if enforce_new_defaults():
-        creds = ctxt.to_policy_values()
-    else:
-        creds = ctxt.to_dict()
+    creds = ctxt.to_policy_values()
     target = target or {}
     try:
         result = _ENFORCER.enforce(rule, target, creds, do_raise, exc)
@@ -102,7 +92,9 @@ def check(rule, ctxt, target=None, do_raise=True, exc=exceptions.Forbidden):
                      {'rule': rule, 'target': repr(target)}, extra=extra)
 
 
-def enforce_new_defaults():
-    if CONF.get('oslo_policy'):
-        return CONF['oslo_policy'].get('enforce_new_defaults', False)
-    return False
+def get_enforcer():
+    # This method is used by oslopolicy CLI scripts in order to generate policy
+    # files from overrides on disk and defaults in code.
+    cfg.CONF([], project='designate')
+    init()
+    return _ENFORCER
