@@ -20,7 +20,7 @@ from designate.backend import impl_bind9
 from designate import context
 from designate import exceptions
 from designate import objects
-from designate.tests import fixtures
+from designate.tests import base_fixtures
 from designate import utils
 
 import subprocess
@@ -28,7 +28,10 @@ import subprocess
 
 class Bind9BackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(Bind9BackendTestCase, self).setUp()
+        super().setUp()
+        self.stdlog = base_fixtures.StandardLogging()
+        self.useFixture(self.stdlog)
+
         self.admin_context = mock.Mock()
         mock.patch.object(
             context.DesignateContext, 'get_admin_context',
@@ -43,17 +46,18 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
             'type': 'bind9',
             'masters': [
-                {'host': '192.168.1.1', 'port': 53},
-                {'host': '192.168.1.2', 'port': 35}
+                {'host': '192.0.2.1', 'port': 53},
+                {'host': '192.0.2.2', 'port': 35}
             ],
             'options': [
-                {'key': 'host', 'value': '192.168.2.3'},
+                {'key': 'host', 'value': '192.0.2.3'},
                 {'key': 'port', 'value': '53'},
-                {'key': 'rndc_host', 'value': '192.168.2.4'},
+                {'key': 'rndc_host', 'value': '192.0.2.4'},
                 {'key': 'rndc_port', 'value': '953'},
                 {'key': 'rndc_bin_path', 'value': '/usr/sbin/rndc'},
                 {'key': 'rndc_config_file', 'value': '/etc/rndc.conf'},
                 {'key': 'rndc_key_file', 'value': '/etc/rndc.key'},
+                {'key': 'rndc_timeout', 'value': '0'},
                 {'key': 'clean_zonefile', 'value': 'true'}
             ],
         }
@@ -64,37 +68,73 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
 
     @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
     def test_create_zone(self, mock_execute):
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.backend.create_zone(self.admin_context, self.zone)
 
         mock_execute.assert_called_with(
             [
                 'addzone',
-                'example.com  { type slave; masters { 192.168.1.1 port 53; 192.168.1.2 port 35;}; file "slave.example.com.cca7908b-dad4-4c50-adba-fb67d4c556e8"; };'  # noqa
+                'example.com  { type slave; masters { 192.0.2.1 port 53; 192.0.2.2 port 35;}; file "slave.example.com.cca7908b-dad4-4c50-adba-fb67d4c556e8"; };'  # noqa
             ]
         )
 
     @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
     def test_update_zone(self, mock_execute):
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.backend.update_zone(self.admin_context, self.zone)
 
         mock_execute.assert_called_with(
             [
                 'modzone',
-                'example.com  { type slave; masters { 192.168.1.1 port 53; 192.168.1.2 port 35;}; file "slave.example.com.cca7908b-dad4-4c50-adba-fb67d4c556e8"; };'  # noqa
+                'example.com  { type slave; masters { 192.0.2.1 port 53; 192.0.2.2 port 35;}; file "slave.example.com.cca7908b-dad4-4c50-adba-fb67d4c556e8"; };'  # noqa
             ]
         )
 
+    @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
+    @mock.patch.object(impl_bind9.Bind9Backend, 'get_zone')
+    def test_update_zone_error(self, mock_get_zone, mock_execute):
+        mock_get_zone.return_value = True
+        mock_execute.side_effect = exceptions.Backend('error')
+
+        with base_fixtures.random_seed(0):
+            self.backend.update_zone(self.admin_context, self.zone)
+
+        self.assertIn('Error updating zone', self.stdlog.logger.output)
+
+    @mock.patch.object(impl_bind9.Bind9Backend, 'create_zone')
+    @mock.patch.object(impl_bind9.Bind9Backend, 'get_zone')
+    def test_update_zone_does_not_exist(self, mock_get_zone, mock_create_zone):
+        mock_get_zone.return_value = False
+
+        self.backend.update_zone(self.admin_context, self.zone)
+
+        mock_create_zone.assert_called()
+
     @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
     def test_get_zone(self, mock_execute):
-        with fixtures.random_seed(0):
+        with base_fixtures.random_seed(0):
             self.backend.get_zone(self.admin_context, self.zone)
 
         mock_execute.assert_called_with(
             ['showzone', 'example.com ']
         )
 
+    @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
+    def test_get_zone_backend_error(self, mock_execute):
+        mock_execute.side_effect = exceptions.Backend('error')
+
+        self.assertRaisesRegex(
+            exceptions.Backend,
+            'error',
+            self.backend.get_zone, self.admin_context, self.zone
+        )
+
+    @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
+    def test_get_zone_backend_error_not_found(self, mock_execute):
+        mock_execute.side_effect = exceptions.Backend('not found')
+
+        self.assertFalse(self.backend.get_zone(self.admin_context, self.zone))
+
     @mock.patch.object(impl_bind9.Bind9Backend, '_execute_rndc')
     def test_create_zone_with_view(self, mock_execute):
         self.target['options'].append(
@@ -105,13 +145,13 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
             objects.PoolTarget.from_dict(self.target)
         )
 
-        with fixtures.random_seed(1):
+        with base_fixtures.random_seed(1):
             backend.create_zone(self.admin_context, self.zone)
 
         mock_execute.assert_called_with(
             [
                 'addzone',
-                'example.com in guest { type slave; masters { 192.168.1.2 port 35; 192.168.1.1 port 53;}; file "slave.example.com.cca7908b-dad4-4c50-adba-fb67d4c556e8"; };'  # noqa
+                'example.com in guest { type slave; masters { 192.0.2.2 port 35; 192.0.2.1 port 53;}; file "slave.example.com.cca7908b-dad4-4c50-adba-fb67d4c556e8"; };'  # noqa
             ]
         )
 
@@ -163,7 +203,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
             objects.PoolTarget.from_dict(self.target)
         )
 
-        backend.delete_zone(self.admin_context, self.zone)
+        backend.delete_zone(self.admin_context, self.zone, {})
 
         mock_execute.assert_called_with(
             ['delzone', 'example.com ']
@@ -186,7 +226,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
     def test_generate_rndc_base_call(self):
         self.assertEqual(
             [
-                '/usr/sbin/rndc', '-s', '192.168.2.4', '-p', '953',
+                '/usr/sbin/rndc', '-s', '192.0.2.4', '-p', '953',
                 '-c', '/etc/rndc.conf', '-k', '/etc/rndc.key'
             ],
             self.backend._generate_rndc_base_call()
@@ -194,7 +234,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
 
     def test_generate_rndc_base_call_without_config_file(self):
         self.target['options'] = [
-            {'key': 'rndc_host', 'value': '192.168.4.4'},
+            {'key': 'rndc_host', 'value': '192.0.2.4'},
             {'key': 'rndc_port', 'value': '953'},
             {'key': 'rndc_bin_path', 'value': '/usr/sbin/rndc'},
             {'key': 'rndc_key_file', 'value': '/etc/rndc.key'},
@@ -206,7 +246,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
 
         self.assertEqual(
             [
-                '/usr/sbin/rndc', '-s', '192.168.4.4', '-p', '953',
+                '/usr/sbin/rndc', '-s', '192.0.2.4', '-p', '953',
                 '-k', '/etc/rndc.key'
             ],
             backend._generate_rndc_base_call()
@@ -214,7 +254,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
 
     def test_generate_rndc_base_call_without_key_file(self):
         self.target['options'] = [
-            {'key': 'rndc_host', 'value': '192.168.3.4'},
+            {'key': 'rndc_host', 'value': '192.0.2.4'},
             {'key': 'rndc_port', 'value': '953'},
             {'key': 'rndc_bin_path', 'value': '/usr/sbin/rndc'},
             {'key': 'rndc_config_file', 'value': '/etc/rndc.conf'},
@@ -226,7 +266,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
 
         self.assertEqual(
             [
-                '/usr/sbin/rndc', '-s', '192.168.3.4', '-p', '953',
+                '/usr/sbin/rndc', '-s', '192.0.2.4', '-p', '953',
                 '-c', '/etc/rndc.conf'
             ],
             backend._generate_rndc_base_call()
@@ -239,7 +279,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
         self.backend._execute_rndc(rndc_op)
 
         mock_execute.assert_called_with(
-            '/usr/sbin/rndc', '-s', '192.168.2.4', '-p', '953',
+            '/usr/sbin/rndc', '-s', '192.0.2.4', '-p', '953',
             '-c', '/etc/rndc.conf', '-k', '/etc/rndc.key',
             'delzone', 'example.com ', timeout=None
         )
@@ -252,7 +292,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
         self.backend._execute_rndc(rndc_op)
 
         mock_execute.assert_called_with(
-            '/usr/sbin/rndc', '-s', '192.168.2.4', '-p', '953',
+            '/usr/sbin/rndc', '-s', '192.0.2.4', '-p', '953',
             '-c', '/etc/rndc.conf', '-k', '/etc/rndc.key',
             'delzone', 'example.com ', timeout=10
         )
@@ -264,7 +304,7 @@ class Bind9BackendTestCase(oslotest.base.BaseTestCase):
         self.backend._rndc_timeout = 10
 
         mock_execute.side_effect = subprocess.TimeoutExpired([
-            '/usr/sbin/rndc', '-s', '192.168.2.4', '-p', '953',
+            '/usr/sbin/rndc', '-s', '192.0.2.4', '-p', '953',
             '-c', '/etc/rndc.conf', '-k', '/etc/rndc.key',
             'delzone', 'example.com '], 10)
 
