@@ -16,10 +16,11 @@
 from unittest import mock
 
 import dns.exception
-from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
 import oslotest.base
 
+from designate.central import rpcapi as central_api
+import designate.conf
 from designate import dnsutils
 from designate import exceptions
 from designate import objects
@@ -27,7 +28,8 @@ from designate.tests.unit import utils
 from designate.worker import processing
 from designate.worker.tasks import zone
 
-CONF = cfg.CONF
+
+CONF = designate.conf.CONF
 
 QUERY_RESULTS = {
     'delete_success_all': {
@@ -97,9 +99,9 @@ QUERY_RESULTS = {
 
 class TestZoneAction(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestZoneAction, self).setUp()
+        super().setUp()
         self.context = mock.Mock()
-        self.pool = 'default_pool'
+        self.pool = mock.Mock()
         self.executor = mock.Mock()
         self.task = zone.ZoneAction(
             self.executor, self.context, self.pool, mock.Mock(), 'CREATE'
@@ -112,12 +114,35 @@ class TestZoneAction(oslotest.base.BaseTestCase):
     def test_call(self):
         self.task._zone_action_on_targets = mock.Mock(return_value=True)
         self.task._poll_for_zone = mock.Mock(return_value=True)
-        result = self.task()
-        self.assertTrue(result)
 
-        self.assertTrue(self.task._wait_for_nameservers.called)
-        self.assertTrue(self.task._zone_action_on_targets.called)
-        self.assertTrue(self.task._poll_for_zone.called)
+        self.assertTrue(self.task())
+
+        self.task._wait_for_nameservers.assert_called()
+        self.task._zone_action_on_targets.assert_called()
+        self.task._poll_for_zone.assert_called()
+
+    @mock.patch.object(zone, 'ZoneActor')
+    @mock.patch.object(zone, 'ZonePoller')
+    def test_call_action_on_targets_false(self, mock_zone_poller,
+                                          mock_zone_actor):
+        mock_zone_poller().return_value = True
+        mock_zone_actor().return_value = False
+
+        self.assertFalse(self.task())
+
+        mock_zone_actor().assert_called_with()
+        mock_zone_poller().assert_not_called()
+
+    @mock.patch.object(zone, 'ZoneActor')
+    @mock.patch.object(zone, 'ZonePoller')
+    def test_call_poll_for_zone_false(self, mock_zone_poller, mock_zone_actor):
+        mock_zone_poller().return_value = False
+        mock_zone_actor().return_value = True
+
+        self.assertFalse(self.task())
+
+        mock_zone_actor().assert_called_with()
+        mock_zone_poller().assert_called_with()
 
     def test_call_on_delete(self):
         mock_zone = mock.Mock()
@@ -152,13 +177,13 @@ class TestZoneAction(oslotest.base.BaseTestCase):
 
 class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestZoneActionOnTarget, self).setUp()
+        super().setUp()
         self.backend = mock.Mock()
         self.target = objects.PoolTarget.from_dict({
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
             'type': 'fake',
             'options': [
-                {'key': 'host', 'value': '127.0.0.1'},
+                {'key': 'host', 'value': '203.0.113.1'},
                 {'key': 'port', 'value': 53},
             ],
             'backend': self.backend,
@@ -166,6 +191,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
 
         self.context = mock.Mock()
         self.executor = mock.Mock()
+        self.zone_params = mock.Mock()
 
     @mock.patch.object(dnsutils, 'notify')
     def test_call_create(self, mock_notify):
@@ -175,16 +201,44 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params
         )
+        self.actor._storage = mock.Mock()
+        self.actor._storage.get_catalog_zone = mock.Mock(
+            side_effect=exceptions.ZoneNotFound)
 
         self.assertTrue(self.actor())
 
         mock_notify.assert_called_once_with(
             self.zone.name,
-            '127.0.0.1',
+            '203.0.113.1',
             port=53
         )
 
+    @mock.patch.object(dnsutils, 'notify')
+    def test_call_create_catalog_zone(self, mock_notify):
+        self.zone = objects.Zone(name='example.org.', action='CREATE')
+        self.actor = zone.ZoneActionOnTarget(
+            self.executor,
+            self.context,
+            self.zone,
+            self.target,
+            self.zone_params
+        )
+
+        self.actor._storage = mock.Mock()
+        self.actor._storage.get_catalog_zone = mock.Mock(
+            return_value=objects.Zone(name='cat.example.org.'))
+        self.assertTrue(self.actor())
+
+        call_catalog_zone = mock.call(
+            'cat.example.org.',
+            '203.0.113.1',
+            port=53
+        )
+
+        mock_notify.assert_has_calls([call_catalog_zone])
+
     @mock.patch.object(dnsutils, 'notify')
     def test_call_update(self, mock_notify):
         self.zone = objects.Zone(name='example.org.', action='UPDATE')
@@ -193,13 +247,17 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params,
         )
+        self.actor._storage = mock.Mock()
+        self.actor._storage.get_catalog_zone = mock.Mock(
+            side_effect=exceptions.ZoneNotFound)
 
         self.assertTrue(self.actor())
 
         mock_notify.assert_called_once_with(
             self.zone.name,
-            '127.0.0.1',
+            '203.0.113.1',
             port=53
         )
 
@@ -211,7 +269,11 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params
         )
+        self.actor._storage = mock.Mock()
+        self.actor._storage.get_catalog_zone = mock.Mock(
+            side_effect=exceptions.ZoneNotFound)
 
         self.assertTrue(self.actor())
 
@@ -227,7 +289,11 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params
         )
+        self.actor.storage.find_pool = mock.Mock()
+        self.actor.storage.get_catalog_zone = mock.Mock(
+            side_effect=exceptions.ZoneNotFound)
 
         self.assertFalse(self.actor())
 
@@ -236,14 +302,14 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
 
 class TestSendNotify(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestSendNotify, self).setUp()
+        super().setUp()
         self.useFixture(cfg_fixture.Config(CONF))
         self.backend = mock.Mock()
         self.target = objects.PoolTarget.from_dict({
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
             'type': 'fake',
             'options': [
-                {'key': 'host', 'value': '127.0.0.1'},
+                {'key': 'host', 'value': '203.0.113.1'},
                 {'key': 'port', 'value': 53},
             ],
         })
@@ -263,7 +329,7 @@ class TestSendNotify(oslotest.base.BaseTestCase):
 
         mock_notify.assert_called_once_with(
             self.zone.name,
-            '127.0.0.1',
+            '203.0.113.1',
             port=53
         )
 
@@ -285,15 +351,19 @@ class TestSendNotify(oslotest.base.BaseTestCase):
 
 class TestZoneActor(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestZoneActor, self).setUp()
+        super().setUp()
         self.context = mock.Mock()
         self.pool = mock.Mock()
         self.executor = mock.Mock()
+        self.zone_params = mock.Mock()
         self.actor = zone.ZoneActor(
             self.executor,
             self.context,
             self.pool,
-            mock.Mock(action='CREATE'),
+            mock.Mock(
+                action='CREATE', name='example.org.', id='123', serial=0
+            ),
+            self.zone_params
         )
 
     def test_threshold_from_config(self):
@@ -302,7 +372,7 @@ class TestZoneActor(oslotest.base.BaseTestCase):
         )
 
         self.assertEqual(
-            cfg.CONF['service:worker'].threshold_percentage,
+            CONF['service:worker'].threshold_percentage,
             actor.threshold_percentage
         )
 
@@ -326,15 +396,15 @@ class TestZoneActor(oslotest.base.BaseTestCase):
 
         self.assertTrue(self.actor._threshold_met(results))
 
-    def test_threshold_met_false(self):
+    @mock.patch.object(central_api.CentralAPI, 'get_instance')
+    def test_threshold_met_false(self, mock_get_instance):
         self.actor._threshold = 90
-        self.actor._update_status = mock.Mock()
 
         results = [False] + [True] * 8 + [False]
 
         self.assertFalse(self.actor._threshold_met(results))
-        self.assertTrue(self.actor._update_status.called)
         self.assertEqual('ERROR', self.actor.zone.status)
+        mock_get_instance.assert_called()
 
 
 @utils.parameterized_class
@@ -353,30 +423,43 @@ class TestParseQueryResults(oslotest.base.BaseTestCase):
         self.assertEqual(case['no_zones'], result.no_zones)
         self.assertEqual(case['consensus_serial'], result.consensus_serial)
 
+    def test_no_serial(self):
+        mock_zone = mock.Mock(
+            action='ERROR', name='example.org.', id='123', serial=1
+        )
+        result = zone.parse_query_results(
+            [None], mock_zone
+        )
+        self.assertEqual(0, result.positives)
+        self.assertEqual(0, result.no_zones)
+        self.assertEqual(0, result.consensus_serial)
+
 
 class TestZonePoller(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestZonePoller, self).setUp()
+        super().setUp()
         self.context = mock.Mock()
         self.pool = mock.Mock()
         self.zone = mock.Mock(name='example.com.', serial=1)
         self.threshold_percentage = 80
         self.executor = mock.Mock()
-        self.poller = zone.ZonePoller(
+        self.task = zone.ZonePoller(
             self.executor,
             self.context,
             self.pool,
             self.zone,
         )
-        self.poller._threshold = self.threshold_percentage
+        self.task._central_api = mock.Mock()
+        self.task._threshold = self.threshold_percentage
 
     def test_constructor(self):
-        self.assertTrue(self.poller)
+        self.assertTrue(self.task)
         self.assertEqual(
-            self.threshold_percentage, self.poller.threshold_percentage
+            self.threshold_percentage, self.task.threshold_percentage
         )
 
-    def test_call_on_success(self):
+    @mock.patch.object(central_api.CentralAPI, 'get_instance')
+    def test_call_on_success(self, mock_get_instance):
         ns_results = [2] * 8 + [0] * 2
         result = zone.DNSQueryResult(
             positives=8,
@@ -384,18 +467,35 @@ class TestZonePoller(oslotest.base.BaseTestCase):
             consensus_serial=2,
             results=ns_results,
         )
-        self.poller.zone.action = 'UPDATE'
-        self.poller.zone.serial = 2
-        self.poller._do_poll = mock.Mock(return_value=result)
-        self.poller._on_success = mock.Mock(return_value=True)
-        self.poller._update_status = mock.Mock()
+        self.task.zone.action = 'UPDATE'
+        self.task.zone.serial = 2
+        self.task._do_poll = mock.Mock(return_value=result)
+        self.task._on_success = mock.Mock(return_value=True)
 
-        self.assertTrue(self.poller())
+        self.assertTrue(self.task())
 
-        self.poller._on_success.assert_called_with(result, 'SUCCESS')
-        self.poller._update_status.called
-        self.poller.zone.serial = 2
-        self.poller.zone.status = 'SUCCESS'
+        self.task._on_success.assert_called_with(result, 'SUCCESS')
+        self.task.zone.serial = 2
+        self.task.zone.status = 'SUCCESS'
+        mock_get_instance.assert_called()
+
+    @mock.patch.object(central_api.CentralAPI, 'get_instance')
+    def test_call_on_failure(self, mock_get_instance):
+        result = zone.DNSQueryResult(
+            positives=8,
+            no_zones=2,
+            consensus_serial=2,
+            results=[0],
+        )
+        self.task.zone.action = 'UPDATE'
+        self.task.zone.serial = 2
+        self.task._do_poll = mock.Mock(return_value=result)
+        self.task._on_failure = mock.Mock(return_value=True)
+
+        self.assertTrue(self.task())
+
+        self.task._on_failure.assert_called_with('NO_ZONE')
+        mock_get_instance.assert_called()
 
     def test_threshold_met_true(self):
         ns_results = [2] * 8 + [0] * 2
@@ -406,7 +506,7 @@ class TestZonePoller(oslotest.base.BaseTestCase):
             results=ns_results,
         )
 
-        success, status = self.poller._threshold_met(result)
+        success, status = self.task._threshold_met(result)
 
         self.assertTrue(success)
         self.assertEqual('SUCCESS', status)
@@ -421,7 +521,7 @@ class TestZonePoller(oslotest.base.BaseTestCase):
             results=ns_results,
         )
 
-        success, status = self.poller._threshold_met(result)
+        success, status = self.task._threshold_met(result)
 
         self.assertFalse(success)
         self.assertEqual('ERROR', status)
@@ -438,10 +538,10 @@ class TestZonePoller(oslotest.base.BaseTestCase):
         )
 
         # Set the threshold to 30%
-        self.poller._threshold = 30
-        self.poller.zone.action = 'UPDATE'
+        self.task._threshold = 30
+        self.task.zone.action = 'UPDATE'
 
-        success, status = self.poller._threshold_met(result)
+        success, status = self.task._threshold_met(result)
 
         self.assertTrue(success)
         self.assertEqual('SUCCESS', status)
@@ -458,10 +558,10 @@ class TestZonePoller(oslotest.base.BaseTestCase):
         )
 
         # Set the threshold to 100%
-        self.poller._threshold = 100
-        self.poller.zone.action = 'UPDATE'
+        self.task._threshold = 100
+        self.task.zone.action = 'UPDATE'
 
-        success, status = self.poller._threshold_met(result)
+        success, status = self.task._threshold_met(result)
 
         self.assertFalse(success)
         self.assertEqual('NO_ZONE', status)
@@ -478,10 +578,10 @@ class TestZonePoller(oslotest.base.BaseTestCase):
         )
 
         # Set the threshold to 100%
-        self.poller._threshold = 100
-        self.poller.zone.action = 'UPDATE'
+        self.task._threshold = 100
+        self.task.zone.action = 'UPDATE'
 
-        success, status = self.poller._threshold_met(result)
+        success, status = self.task._threshold_met(result)
 
         self.assertFalse(success)
         self.assertEqual('NO_ZONE', status)
@@ -489,20 +589,20 @@ class TestZonePoller(oslotest.base.BaseTestCase):
     def test_on_success(self):
         query_result = mock.Mock(consensus_serial=10)
 
-        result = self.poller._on_success(query_result, 'FOO')
+        result = self.task._on_success(query_result, 'FOO')
 
         self.assertTrue(result)
         self.assertEqual(10, self.zone.serial)
         self.assertEqual('FOO', self.zone.status)
 
     def test_on_error_failure(self):
-        result = self.poller._on_failure('FOO')
+        result = self.task._on_failure('FOO')
 
         self.assertFalse(result)
         self.assertEqual('FOO', self.zone.status)
 
     def test_on_no_zones_failure(self):
-        result = self.poller._on_failure('NO_ZONE')
+        result = self.task._on_failure('NO_ZONE')
 
         self.assertFalse(result)
         self.assertEqual('NO_ZONE', self.zone.status)
@@ -511,7 +611,7 @@ class TestZonePoller(oslotest.base.BaseTestCase):
 
 class TestZonePollerPolling(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestZonePollerPolling, self).setUp()
+        super().setUp()
         self.executor = processing.Executor()
         self.context = mock.Mock()
         self.zone = mock.Mock(name='example.com.', action='UPDATE', serial=10)
@@ -572,7 +672,7 @@ class TestZonePollerPolling(oslotest.base.BaseTestCase):
 
 class TestUpdateStatus(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestUpdateStatus, self).setUp()
+        super().setUp()
         self.executor = processing.Executor()
         self.task = zone.UpdateStatus(self.executor, mock.Mock(), mock.Mock())
         self.task._central_api = mock.Mock()
@@ -586,7 +686,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
 
         self.assertEqual('DELETE', self.task.zone.action)
         self.assertEqual('SUCCESS', self.task.zone.status)
-        self.assertTrue(self.task.central_api.update_status.called)
+        self.task.central_api.update_status.assert_called()
 
     def test_call_on_success(self):
         self.task.zone.action = 'UPDATE'
@@ -596,7 +696,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
         self.task()
 
         self.assertEqual('UPDATE', self.task.zone.action)
-        self.assertTrue(self.task.central_api.update_status.called)
+        self.task.central_api.update_status.assert_called()
 
     def test_call_central_call(self):
         self.task.zone.status = 'SUCCESS'
@@ -621,7 +721,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
 
         self.assertEqual('DELETE', self.task.zone.action)
         self.assertEqual('ERROR', self.task.zone.status)
-        self.assertTrue(self.task.central_api.update_status.called)
+        self.task.central_api.update_status.assert_called()
 
     def test_call_on_create_error(self):
         self.task.zone.action = 'CREATE'
@@ -632,7 +732,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
 
         self.assertEqual('CREATE', self.task.zone.action)
         self.assertEqual('ERROR', self.task.zone.status)
-        self.assertTrue(self.task.central_api.update_status.called)
+        self.task.central_api.update_status.assert_called()
 
     def test_call_on_update_error(self):
         self.task.zone.action = 'UPDATE'
@@ -643,12 +743,12 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
 
         self.assertEqual('UPDATE', self.task.zone.action)
         self.assertEqual('ERROR', self.task.zone.status)
-        self.assertTrue(self.task.central_api.update_status.called)
+        self.task.central_api.update_status.assert_called()
 
 
 class TestPollForZone(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestPollForZone, self).setUp()
+        super().setUp()
         self.zone = mock.Mock(serial=1)
         self.zone.name = 'example.org.'
         self.executor = processing.Executor()
@@ -692,7 +792,8 @@ class TestPollForZone(oslotest.base.BaseTestCase):
 
 class TestExportZone(oslotest.base.BaseTestCase):
     def setUp(self):
-        super(TestExportZone, self).setUp()
+        super().setUp()
+        self.useFixture(cfg_fixture.Config(CONF))
         self.zone = mock.Mock(name='example.com.', serial=1)
         self.export = mock.Mock()
         self.export.id = '1'
@@ -708,7 +809,6 @@ class TestExportZone(oslotest.base.BaseTestCase):
 
         self.task._quota.limit_check = mock.Mock()
         self.task._storage.count_recordsets = mock.Mock(return_value=1)
-        self.task._synchronous_export = mock.Mock(return_value=True)
 
     def test_sync_export_right_size(self):
         self.task()
@@ -726,7 +826,7 @@ class TestExportZone(oslotest.base.BaseTestCase):
         self.assertEqual('ERROR', self.export.status)
 
     def test_async_export_fails(self):
-        self.task._synchronous_export = mock.Mock(return_value=False)
+        CONF.set_override('export_synchronous', False, 'service:worker')
 
         self.task()
         self.assertEqual('ERROR', self.export.status)
